FileData class

Constructors

FileData({bool hasFile = false, String fileName = "", String filePath = "", String fileMimeType = "", String path = "", String otherDevicePath = ""})
FileData.clone(FileData fileData)
factory

Properties

fileMimeType ↔ String
getter/setter pair
fileName ↔ String
getter/setter pair
filePath ↔ String
getter/setter pair
hasFile ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
otherDevicePath ↔ String
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited