FilePicker class

pre-define file picker widget

Inheritance

Constructors

FilePicker({Key? key, required BuildContext context, required FileData fileData, required dynamic onSelected(FileData fileData), dynamic onOtherDeviceSelected(FileData fileData)?, dynamic onCancel(String message, int messageCode)?, dynamic onDeleted(FileData fileData)?, dynamic onView(FileData fileData)?, bool camera = true, bool gallery = true, bool document = true, bool otherDevice = false, bool view = true, bool delete = true, bool crop = true, int? maxFileSizeInMb, bool cropOnlySquare = false, String cropperToolbarTitle = Files.cropperToolbarTitle, Color cropperToolbarColor = Files.cropperToolbarColor, Color cropperToolbarWidgetsColor = Files.cropperToolbarWidgetsColor, List<String>? allowedExtensions, double? width, double? height, Widget? child})
const

Properties

allowedExtensions → List<String>?
final
camera → bool
final
child → Widget?
final
context → BuildContext
final
crop → bool
final
cropOnlySquare → bool
final
cropperToolbarColor → Color
final
cropperToolbarTitle → String
final
cropperToolbarWidgetsColor → Color
final
delete → bool
final
document → bool
final
fileData → FileData
final
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxFileSizeInMb → int?
final
onCancel → dynamic Function(String message, int messageCode)?
final
onDeleted → dynamic Function(FileData fileData)?
final
onOtherDeviceSelected → dynamic Function(FileData fileData)?
final
onSelected → dynamic Function(FileData fileData)
final
onView → dynamic Function(FileData fileData)?
final
otherDevice → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view → bool
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FilePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited